@@ -4,12 +4,17 @@
 <context>
     <name>BandpassDialog</name>
     <message>
-        <location filename="bandpassdialog.ui" line="42"/>
+        <location filename="bandpassdialog.ui" line="14"/>
+        <source>Alignment</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="bandpassdialog.ui" line="28"/>
         <source>Curve gain (dB)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="bandpassdialog.ui" line="59"/>
+        <location filename="bandpassdialog.ui" line="57"/>
         <source>Curve ripple (0.7 = 0dB)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -288,7 +293,7 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="1080"/>
-        <location filename="mainwindow.cpp" line="1109"/>
+        <location filename="mainwindow.cpp" line="1121"/>
         <source>About QSpeakers</source>
         <translation type="unfinished"></translation>
     </message>
@@ -437,11 +442,6 @@
         <source>Curve Plot</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="mainwindow.ui" line="1227"/>
-        <source>Open recent</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="mainwindow.ui" line="1169"/>
         <source>Zbinden M4</source>
@@ -548,109 +548,108 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="187"/>
+        <location filename="mainwindow.cpp" line="192"/>
         <source>Export File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="187"/>
-        <location filename="mainwindow.cpp" line="214"/>
+        <location filename="mainwindow.cpp" line="192"/>
+        <location filename="mainwindow.cpp" line="219"/>
         <source>QSpeakers project (*.qsp)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="187"/>
+        <location filename="mainwindow.cpp" line="192"/>
         <source>untitled.qsp</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="206"/>
-        <location filename="mainwindow.cpp" line="326"/>
+        <location filename="mainwindow.cpp" line="211"/>
+        <location filename="mainwindow.cpp" line="332"/>
         <source>Project not saved</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="207"/>
+        <location filename="mainwindow.cpp" line="212"/>
         <source>The current project has not been saved. Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="214"/>
+        <location filename="mainwindow.cpp" line="219"/>
         <source>Import File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="221"/>
-        <location filename="mainwindow.cpp" line="230"/>
+        <location filename="mainwindow.cpp" line="226"/>
+        <location filename="mainwindow.cpp" line="235"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="221"/>
-        <location filename="mainwindow.cpp" line="230"/>
+        <location filename="mainwindow.cpp" line="226"/>
+        <location filename="mainwindow.cpp" line="235"/>
         <source>Could not open project!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="248"/>
-        <source>&amp;%1 %2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="327"/>
+        <location filename="mainwindow.cpp" line="333"/>
         <source>The current project has not been saved. Exit anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="561"/>
+        <location filename="mainwindow.cpp" line="567"/>
         <source>Export for Gnuplot</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="561"/>
+        <location filename="mainwindow.cpp" line="567"/>
         <source>Gnuplot data (*.dat)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="576"/>
+        <location filename="mainwindow.cpp" line="582"/>
         <source>Export for 3D OpenSCAD</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="576"/>
-        <location filename="mainwindow.cpp" line="591"/>
+        <location filename="mainwindow.cpp" line="582"/>
+        <location filename="mainwindow.cpp" line="597"/>
         <source>OpenSCAD script (*.scad)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="591"/>
+        <location filename="mainwindow.cpp" line="597"/>
         <source>Export for 2D OpenSCAD</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="928"/>
+        <location filename="mainwindow.cpp" line="940"/>
         <source>Removal confirmation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="929"/>
+        <location filename="mainwindow.cpp" line="941"/>
         <source>Do you really want to remove this loudspeaker from the database?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1110"/>
-        <source>QSpeakers version </source>
+        <location filename="mainwindow.cpp" line="1122"/>
+        <source>QSpeakers version %1 (%2)
+
+This program simulates common acoustical enclosures behaviour to help designing loudspeaker systems.
+
+This program is free software, copyright (C) 2014 Benoit Rouits &lt;brouits@free.fr&gt; and released under the GNU General Public Lisence version 3. It is delivered as is in the hope it can be useful, but with no warranty at all.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1246"/>
-        <location filename="mainwindow.cpp" line="1303"/>
+        <location filename="mainwindow.cpp" line="1261"/>
+        <location filename="mainwindow.cpp" line="1318"/>
         <source>Unsaved speaker</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1247"/>
-        <location filename="mainwindow.cpp" line="1304"/>
+        <location filename="mainwindow.cpp" line="1262"/>
+        <location filename="mainwindow.cpp" line="1319"/>
         <source>This speaker is not present in the database. Would you like to insert it before to continue?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -678,35 +677,35 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="bandpassbox.cpp" line="153"/>
+        <location filename="bandpassbox.cpp" line="154"/>
         <source>Sealed Vol. %1 L</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="154"/>
+        <location filename="bandpassbox.cpp" line="155"/>
         <source>Ported Vol. %1 L</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="157"/>
+        <location filename="bandpassbox.cpp" line="158"/>
         <location filename="portedbox.cpp" line="197"/>
         <source>Port Diam. %1 cm</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="162"/>
+        <location filename="bandpassbox.cpp" line="163"/>
         <location filename="portedbox.cpp" line="201"/>
         <source>Port Len. %1 cm</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="163"/>
+        <location filename="bandpassbox.cpp" line="164"/>
         <location filename="portedbox.cpp" line="202"/>
         <source>Port Num. %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="164"/>
+        <location filename="bandpassbox.cpp" line="165"/>
         <location filename="portedbox.cpp" line="203"/>
         <source>Fb %1 Hz</source>
         <translation type="unfinished"></translation>
@@ -718,13 +717,13 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="159"/>
+        <location filename="bandpassbox.cpp" line="160"/>
         <location filename="portedbox.cpp" line="199"/>
         <source>Slot port %1 x %2 cm</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="system.cpp" line="83"/>
+        <location filename="system.cpp" line="84"/>
         <source>Driver(s) number: </source>
         <translation type="unfinished"></translation>
     </message>
@@ -768,6 +767,11 @@
         <source>applying bandpass box alignment</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="main.cpp" line="40"/>
+        <source>Loudspeaker enclosure computation program.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchDialog</name>
@@ -790,105 +794,110 @@
 <context>
     <name>SpeakerDialog</name>
     <message>
-        <location filename="speakerdialog.ui" line="22"/>
+        <location filename="speakerdialog.ui" line="14"/>
+        <source>Loudspeaker</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="speakerdialog.ui" line="32"/>
         <source>Vendor</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="29"/>
+        <location filename="speakerdialog.ui" line="39"/>
         <source>speaker vendor name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="36"/>
+        <location filename="speakerdialog.ui" line="46"/>
         <source>Model</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="43"/>
+        <location filename="speakerdialog.ui" line="53"/>
         <source>speaker name or reference number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="50"/>
+        <location filename="speakerdialog.ui" line="60"/>
         <source>Fs (Hz)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="67"/>
+        <location filename="speakerdialog.ui" line="77"/>
         <source>Qts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="81"/>
+        <location filename="speakerdialog.ui" line="91"/>
         <source>Vas (L)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="98"/>
-        <source>Dia (m)</source>
+        <location filename="speakerdialog.ui" line="108"/>
+        <source>Dia cutout (m)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="115"/>
+        <location filename="speakerdialog.ui" line="125"/>
         <source>Z (Ohm)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="129"/>
+        <location filename="speakerdialog.ui" line="139"/>
         <source>Sd (m²)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="143"/>
+        <location filename="speakerdialog.ui" line="153"/>
         <source>Re (Ohm)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="157"/>
+        <location filename="speakerdialog.ui" line="167"/>
         <source>Le (mH)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="171"/>
+        <location filename="speakerdialog.ui" line="181"/>
         <source>Xmax (mm)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="185"/>
+        <location filename="speakerdialog.ui" line="195"/>
         <source>Qms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="199"/>
+        <location filename="speakerdialog.ui" line="209"/>
         <source>Qes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="213"/>
+        <location filename="speakerdialog.ui" line="223"/>
         <source>Spl (dB)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="230"/>
+        <location filename="speakerdialog.ui" line="240"/>
         <source>Pe (W)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="247"/>
+        <location filename="speakerdialog.ui" line="257"/>
         <source>BL (Tm)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="speakerdialog.ui" line="261"/>
-        <source>Voice Coil</source>
+        <location filename="speakerdialog.ui" line="271"/>
+        <source>Voice Coil (#)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>main</name>
     <message>
-        <location filename="main.cpp" line="44"/>
+        <location filename="main.cpp" line="43"/>
         <source>Project file to work on.</source>
         <translation type="unfinished"></translation>
     </message>
