@@ -20,7 +20,9 @@
 
 QString SpeakerDb::getPath(void)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+    QString prefix = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
+#elif QT_VERSION >= QT_VERSION_CHECK(5,0,0)
     QString prefix = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
 #else
     QString prefix = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
